"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Bindings = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const mixins_1 = require("../mixins");
const reflection_1 = require("../constants/reflection");
exports.Bindings = {
    deleteOne: {
        method: common_1.RequestMethod.DELETE,
        path: `:${reflection_1.PARAMS_RESOURCE_ID}`,
        name: 'deleteOne',
        implementation: function (id) {
            return this.serviceMixin.deleteOne({ route: { id } });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin,
                ]
            }
        ],
    },
    deleteRelationship: {
        method: common_1.RequestMethod.DELETE,
        name: 'deleteRelationship',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/relationships/:${reflection_1.PARAMS_RELATION_NAME}`,
        implementation: function (id, relName, body) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.deleteRelationship({
                    route: { id, relName },
                    body,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
            {
                property: 'data',
                decorator: common_1.Body,
                mixins: [
                    mixins_1.bodyDeleteRelationshipMixin,
                ],
            }
        ],
    },
    getAll: {
        method: common_1.RequestMethod.GET,
        name: 'getAll',
        path: '',
        implementation: function (query) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.getAll({ query });
            });
        },
        parameters: [
            {
                decorator: common_1.Query,
                mixins: [
                    mixins_1.querySchemaMixin,
                    mixins_1.queryParamsMixin,
                ]
            }
        ]
    },
    getOne: {
        method: common_1.RequestMethod.GET,
        name: 'getOne',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}`,
        implementation: function (id, query) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.getOne({
                    route: { id },
                    query,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin,
                ]
            },
            {
                decorator: common_1.Query,
                mixins: [
                    mixins_1.querySchemaMixin,
                    mixins_1.queryParamsMixin,
                ]
            }
        ]
    },
    getRelationship: {
        method: common_1.RequestMethod.GET,
        name: 'getRelationship',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/relationships/:${reflection_1.PARAMS_RELATION_NAME}`,
        implementation: function (id, relName) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.getRelationship({
                    route: { id, relName },
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
        ]
    },
    getDirectOne: {
        method: common_1.RequestMethod.GET,
        name: 'getDirectOne',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/:${reflection_1.PARAMS_RELATION_NAME}/:${reflection_1.PARAMS_RELATION_ID}`,
        implementation: function (id, relName, relId, query) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.getDirectOne({
                    route: { id, relName, relId },
                    query,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                decorator: common_1.Query,
                mixins: [
                    mixins_1.querySchemaMixin,
                    mixins_1.queryParamsMixin,
                ]
            }
        ]
    },
    getDirectAll: {
        method: common_1.RequestMethod.GET,
        name: 'getDirectAll',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/:${reflection_1.PARAMS_RELATION_NAME}`,
        implementation: function (id, relName, query) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.getDirectAll({
                    route: { id, relName },
                    query,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
            {
                decorator: common_1.Query,
                mixins: [
                    mixins_1.querySchemaMixin,
                    mixins_1.queryParamsMixin,
                ]
            }
        ]
    },
    patchOne: {
        method: common_1.RequestMethod.PATCH,
        name: 'patchOne',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}`,
        implementation: function (id, body) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.patchOne({
                    route: { id },
                    body,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: 'data',
                decorator: common_1.Body,
                mixins: [
                    mixins_1.bodyPatchMixin
                ],
            },
        ]
    },
    patchRelationship: {
        method: common_1.RequestMethod.PATCH,
        name: 'patchRelationship',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/relationships/:${reflection_1.PARAMS_RELATION_NAME}`,
        implementation: function (id, relName, body) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.patchRelationship({
                    route: { id, relName },
                    body,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
            {
                property: 'data',
                decorator: common_1.Body,
                mixins: [
                    mixins_1.bodyPatchRelationshipMixin
                ],
            },
        ]
    },
    postOne: {
        method: common_1.RequestMethod.POST,
        name: 'postOne',
        path: '',
        implementation: function (body) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.postOne({
                    body,
                });
            });
        },
        parameters: [
            {
                property: 'data',
                decorator: common_1.Body,
                mixins: [
                    mixins_1.bodyPostMixin
                ],
            },
        ]
    },
    postRelationship: {
        method: common_1.RequestMethod.POST,
        name: 'postRelationship',
        path: `:${reflection_1.PARAMS_RESOURCE_ID}/relationships/:${reflection_1.PARAMS_RELATION_NAME}`,
        implementation: function (id, relName, body) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                return this.serviceMixin.postRelationship({
                    route: { id, relName },
                    body,
                });
            });
        },
        parameters: [
            {
                property: reflection_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseResourceIdMixin
                ],
            },
            {
                property: reflection_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [
                    mixins_1.parseRelationshipNameMixin
                ],
            },
            {
                property: 'data',
                decorator: common_1.Body,
                mixins: [
                    mixins_1.bodyPostRelationshipMixin
                ],
            },
        ]
    }
};
//# sourceMappingURL=bindings.js.map