"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.preparePostgresError = void 0;
const common_1 = require("@nestjs/common");
const types_1 = require("../../../types");
function preparePostgresError(context, error) {
    const request = context.switchToHttp().getRequest();
    const errors = [];
    switch (error.code) {
        case types_1.PostgresErrors.InvalidTimestamp:
        case types_1.PostgresErrors.InvalidType: {
            Object.entries(request.query.filter || {})
                .forEach(([key, value]) => {
                const test = typeof value === 'object' ? Object.values(value).pop() : value;
                if (error.message.includes(`"${test}"`)) {
                    errors.push({
                        detail: `Filter param '${key}' has invalid type`,
                        source: {
                            parameter: "filter" /* filter */,
                        },
                    });
                }
            });
            break;
        }
        case types_1.PostgresErrors.DuplicateKey: {
            const matches = error.detail.match(/(?<=\().+?(?=\))/gm);
            errors.push({
                source: {
                    pointer: `/data/attributes/${matches[0]}`
                },
                detail: `Duplicate value '${matches[1]}' in the '${matches[0]}' attribute`
            });
            break;
        }
        case types_1.PostgresErrors.KeyConstraint: {
            errors.push({
                detail: 'You must clean entity relationships before this operation'
            });
            break;
        }
        case types_1.PostgresErrors.OperatorDoesNotExist: {
            errors.push({
                detail: 'Filter params contain invalid operator',
                source: {
                    parameter: "filter" /* filter */,
                },
            });
            break;
        }
    }
    return new common_1.HttpException({ errors }, 409);
}
exports.preparePostgresError = preparePostgresError;
//# sourceMappingURL=prepare-postgres-error.js.map