"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.props = void 0;
const common_1 = require("@nestjs/common");
const param_case_1 = require("param-case");
const swagger_service_1 = require("../services/swagger/swagger.service");
function props(controller, entity, config) {
    const entityName = entity instanceof Function ? entity.name : entity.options.name;
    const urlName = param_case_1.paramCase(entityName);
    const { name, path, parameters, method, implementation } = config;
    if (!controller.prototype[name]) {
        controller.prototype[name] = function (...args) {
            return implementation.call(this, ...args);
        };
    }
    const descriptor = Object.getOwnPropertyDescriptor(controller.prototype, name);
    switch (method) {
        case common_1.RequestMethod.GET: {
            common_1.Get(path)(controller.prototype, name, descriptor);
            break;
        }
        case common_1.RequestMethod.POST: {
            common_1.Post(path)(controller.prototype, name, descriptor);
            break;
        }
        case common_1.RequestMethod.PATCH: {
            common_1.Patch(path)(controller.prototype, name, descriptor);
            break;
        }
        case common_1.RequestMethod.DELETE: {
            common_1.Delete(path)(controller.prototype, name, descriptor);
            break;
        }
        default: {
            throw new Error(`Method '${method}' unsupported`);
        }
    }
    parameters.forEach((parameter, key) => {
        const { property, decorator, mixins } = parameter;
        decorator(property, ...(mixins.map(mixin => mixin(entity))))(controller.prototype, name, key);
    });
    const swaggerPath = `/${urlName}` + (path ? `/${path}` : '');
    swagger_service_1.SwaggerService.addRouteConfig(entity, swaggerPath, name);
}
exports.props = props;
//# sourceMappingURL=props.js.map