"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkClassValidatorFields = void 0;
const tslib_1 = require("tslib");
const class_validator_1 = require("class-validator");
function checkClassValidatorFields(resourceData, entityMetadata, isSkipUndefined = true) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const generalErrors = [];
        const temporaryEntity = new entityMetadata.target;
        Object
            .entries(resourceData.relationships || {})
            .forEach(([key, val]) => {
            temporaryEntity[key] = val.data;
        });
        Object
            .entries(resourceData.attributes || {})
            .forEach(([key, val]) => {
            temporaryEntity[key] = val;
        });
        const validationErrors = yield class_validator_1.validate(temporaryEntity, {
            skipUndefinedProperties: isSkipUndefined,
        });
        if (validationErrors.length > 0) {
            validationErrors.forEach(error => {
                Object.values(error.constraints).forEach(message => {
                    const relation = entityMetadata.relations.find(relation => relation.propertyPath === error.property);
                    if (!relation) {
                        generalErrors.push({
                            source: { pointer: `/data/attributes/${error.property}` },
                            detail: message,
                        });
                    }
                    else {
                        generalErrors.push({
                            source: { pointer: `/data/relationships/${error.property}` },
                            detail: message,
                        });
                    }
                });
            });
        }
        return generalErrors;
    });
}
exports.checkClassValidatorFields = checkClassValidatorFields;
//# sourceMappingURL=check-class-validator-fields.js.map