"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkQueryFilterParam = void 0;
const tslib_1 = require("tslib");
const __1 = require("..");
const types_1 = require("../../../types");
function checkQueryFilterParam(queryParams, entityMetadata) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const relations = entityMetadata.relations.map(item => item.propertyPath);
        const errors = [];
        (Object.entries(queryParams["filter" /* filter */] || {})).forEach(([name, value]) => {
            const [operand, filterValue] = Object.entries(value).pop();
            if (relations.includes(name) && (name.split('.').length === 1)) {
                if (![types_1.FilterOperand.eq, types_1.FilterOperand.ne].includes(operand)) {
                    errors.push({
                        detail: `Allowed only '${types_1.FilterOperand.eq}' and '${types_1.FilterOperand.ne}' operands in field '${name}'`,
                        source: {
                            parameter: "filter" /* filter */,
                        },
                    });
                    return;
                }
                if (filterValue !== 'null') {
                    errors.push({
                        detail: `You can use only 'null' value in field '${name}'`,
                        source: {
                            parameter: "filter" /* filter */,
                        },
                    });
                    return;
                }
            }
            else {
                if (!types_1.OperandsMap[operand]) {
                    errors.push({
                        detail: `Incorrect operand '${operand}' in field '${name}'`,
                        source: {
                            parameter: "filter" /* filter */,
                        },
                    });
                    return;
                }
            }
            errors.push(...__1.checkEntityFieldMetadata(name, queryParams, entityMetadata, "filter" /* filter */));
        });
        return errors;
    });
}
exports.checkQueryFilterParam = checkQueryFilterParam;
//# sourceMappingURL=check-query-filter-param.js.map