"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkQueryParamsSchema = void 0;
const tslib_1 = require("tslib");
const ajv_1 = require("ajv");
const querySchema = require("../../../schema/query.json");
const ajv = new ajv_1.default({ allErrors: true });
function checkQueryParamsSchema(query) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const validateFunction = ajv.compile(querySchema);
        const validate = validateFunction(query);
        const errors = [];
        if (!validate) {
            validateFunction.errors.forEach(error => {
                const parameterParts = error.dataPath.split('/').filter(value => value !== '');
                switch (error.keyword) {
                    case 'uniqueItems':
                        errors.push({
                            source: { parameter: parameterParts[0] },
                            detail: `Query parameter '${parameterParts.join('.')}' values must be unique`,
                        });
                        break;
                    case 'minProperties':
                    case 'minItems':
                        errors.push({
                            source: { parameter: parameterParts[0] },
                            detail: `Query parameter '${parameterParts.join('.')}' must not have less than ${error.params.limit} items`,
                        });
                        break;
                    case 'type':
                        errors.push({
                            source: { parameter: parameterParts[0] },
                            detail: `Query parameter '${parameterParts.join('.')}' must be of '${error.params.type}' type`,
                        });
                        break;
                    case 'minimum':
                        errors.push({
                            source: { parameter: parameterParts[0] },
                            detail: `Query parameter '${parameterParts.join('.')}' must be greater or equal to ${error.params.limit}`,
                        });
                        break;
                    default:
                        errors.push({
                            source: { parameter: parameterParts[0] },
                            detail: error.message,
                        });
                }
            });
        }
        return errors;
    });
}
exports.checkQueryParamsSchema = checkQueryParamsSchema;
//# sourceMappingURL=check-query-params-schema.js.map