"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkRelationDataBasicInfo = void 0;
const tslib_1 = require("tslib");
const param_case_1 = require("param-case");
function checkRelationDataBasicInfo(relationData, relationMetadata, isDataRequired = true) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const generalErrors = [];
        const valueArray = !Array.isArray(relationData) ? [relationData] : relationData;
        valueArray.forEach(item => {
            if ((item === null) && !isDataRequired) {
                return;
            }
            if (!item.id) {
                generalErrors.push({
                    source: { pointer: '/data' },
                    detail: "Data must have an 'id' definition",
                });
            }
            if (item.id && (Number.isNaN(parseInt(item.id, 10)) || `${parseInt(item.id, 10)}` !== item.id)) {
                generalErrors.push({
                    source: { pointer: '/data/id' },
                    detail: "Data 'id' definition is not a number",
                });
            }
            if (!item.type) {
                generalErrors.push({
                    source: { pointer: '/data' },
                    detail: "Data must have a 'type' definition",
                });
            }
            const relationTypeName = param_case_1.paramCase(relationMetadata.inverseEntityMetadata.name);
            if (item.type && (item.type !== relationTypeName)) {
                generalErrors.push({
                    source: { pointer: '/data/type' },
                    detail: `Data 'type' definition is not equal to the '${relationTypeName}' relation`,
                });
            }
        }, []);
        return generalErrors;
    });
}
exports.checkRelationDataBasicInfo = checkRelationDataBasicInfo;
//# sourceMappingURL=check-relation-data-basic-info.js.map