"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkResourceRelationsData = void 0;
const tslib_1 = require("tslib");
const param_case_1 = require("param-case");
function checkResourceRelationsData(resourceData, entityMetadata, isDataRequired = true) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return Object
            .entries(resourceData.relationships)
            .reduce((accum, [key, value]) => {
            if (isDataRequired && !value.data) {
                accum.push({
                    source: { pointer: `/data/relationships/${key}` },
                    detail: "Relation must have a 'data' definition",
                });
                return accum;
            }
            if (value.data === null) {
                return accum;
            }
            const data = Array.isArray(value.data) ? value.data : [value.data];
            data.forEach(item => {
                const { type, id } = item;
                if (!item.id) {
                    accum.push({
                        source: { pointer: `/data/relationships/${key}/data` },
                        detail: "Data must have an 'id' definition",
                    });
                }
                if (id && (Number.isNaN(parseInt(id, 10)) || `${parseInt(id, 10)}` !== `${id}`)) {
                    accum.push({
                        source: { pointer: `/data/relationships/${key}/data/id` },
                        detail: "Data 'id' definition is not a number",
                    });
                }
                if (!type) {
                    accum.push({
                        source: { pointer: `/data/relationships/${key}/data` },
                        detail: "Data must have a 'type' definition",
                    });
                }
                const meta = entityMetadata.relations.find(relation => relation.propertyPath === key);
                const typeName = param_case_1.paramCase(meta.inverseEntityMetadata.name);
                if (type && (typeName !== type)) {
                    accum.push({
                        source: { pointer: `/data/relationships/${key}/data/type` },
                        detail: `Data 'type' definition is not equal to the '${typeName}' relation`,
                    });
                }
            });
            return accum;
        }, []);
    });
}
exports.checkResourceRelationsData = checkResourceRelationsData;
//# sourceMappingURL=check-resource-relations-data.js.map