"use strict";
var JsonApiModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonApiModule = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const core_1 = require("@nestjs/core");
const swaggerUi = require("swagger-ui-express");
const typeorm_2 = require("typeorm");
const swagger_service_1 = require("./services/swagger/swagger.service");
const constants_1 = require("./constants");
const mixins_1 = require("./mixins");
let JsonApiModule = JsonApiModule_1 = class JsonApiModule {
    constructor(connection, adapterHost) {
        this.connection = connection;
        this.adapterHost = adapterHost;
    }
    onModuleInit() {
        swagger_service_1.SwaggerService.getEntities().forEach((entity) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.connection.getRepository(entity);
            swagger_service_1.SwaggerService.addResourceConfig(repository.metadata);
        }));
        const config = swagger_service_1.SwaggerService.getConfig();
        if (!config.hideSwaggerRoute) {
            const document = swagger_service_1.SwaggerService.prepareDocument();
            const { httpAdapter } = this.adapterHost;
            const swaggerHtml = swaggerUi.generateHTML(document, {});
            httpAdapter.get(`/${config.prefix}`, (req, res) => res.send(swaggerHtml));
            httpAdapter.use(`/${config.prefix}`, swaggerUi.serveFiles(document, {}));
        }
    }
    static forRoot(options) {
        const { globalPrefix } = options;
        const optionsProviders = options.providers || [];
        const moduleParams = {
            module: JsonApiModule_1,
            controllers: [],
            providers: [
                ...optionsProviders,
                {
                    provide: constants_1.JSON_API_CONFIG,
                    useValue: {
                        globalPrefix,
                    },
                },
            ],
            imports: [typeorm_1.TypeOrmModule.forFeature(options.entities)],
        };
        const swaggerOptions = options.swagger || {};
        swagger_service_1.SwaggerService.setConfig(Object.assign(Object.assign({}, swaggerOptions), { apiPrefix: swaggerOptions.apiPrefix || globalPrefix }));
        options.entities.forEach((entity) => {
            const controller = (options.controllers || []).find((item) => Reflect.getMetadata(constants_1.JSON_API_ENTITY, item) === entity);
            const module = mixins_1.moduleMixin(globalPrefix, controller, entity);
            moduleParams.controllers = [...moduleParams.controllers, module.controller];
            moduleParams.providers = [...moduleParams.providers, ...module.providers];
            swagger_service_1.SwaggerService.addEntity(entity);
        });
        return moduleParams;
    }
};
JsonApiModule = JsonApiModule_1 = tslib_1.__decorate([
    common_1.Module({}),
    tslib_1.__param(0, typeorm_1.InjectConnection()),
    tslib_1.__metadata("design:paramtypes", [typeorm_2.Connection,
        core_1.HttpAdapterHost])
], JsonApiModule);
exports.JsonApiModule = JsonApiModule;
//# sourceMappingURL=json-api.module.js.map