"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moduleMixin = void 0;
const common_1 = require("@nestjs/common");
const constants_1 = require("@nestjs/common/constants");
const param_case_1 = require("param-case");
const helpers_1 = require("../../helpers");
const bindings_1 = require("../../config/bindings");
const __1 = require("..");
function moduleMixin(globalPrefix, controller, entity) {
    const entityName = entity instanceof Function ? entity.name : entity.options.name;
    const builtController = controller || class ControllerMixin {
    };
    const builtTransform = __1.transformMixin(entity);
    const builtService = __1.serviceMixin(entity, builtTransform);
    common_1.Controller(`${globalPrefix}/${param_case_1.paramCase(entityName)}`)(builtController);
    common_1.Inject(builtService)(builtController.prototype, 'serviceMixin');
    common_1.UseInterceptors(__1.interceptorMixin())(builtController);
    const properties = Reflect.getMetadata(constants_1.PROPERTY_DEPS_METADATA, builtController);
    const serviceToken = helpers_1.getServiceToken(builtController);
    if (properties.find(item => item.type === serviceToken)) {
        const serviceProp = properties.find(item => item.type === serviceToken);
        const restProps = properties.filter(item => item.type !== serviceToken);
        serviceProp.type = builtService.name;
        Reflect.defineMetadata(constants_1.PROPERTY_DEPS_METADATA, [serviceProp, ...restProps], builtController);
    }
    Object.values(bindings_1.Bindings).forEach(config => {
        helpers_1.props(builtController, entity, config);
    });
    return {
        controller: helpers_1.mixin(builtController),
        providers: [
            builtTransform,
            builtService
        ]
    };
}
exports.moduleMixin = moduleMixin;
//# sourceMappingURL=module.mixin.js.map