"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryParamsMixin = void 0;
const tslib_1 = require("tslib");
const typeorm_1 = require("@nestjs/typeorm");
const core_1 = require("@nestjs/core");
const common_1 = require("@nestjs/common");
const constants_1 = require("../../../constants");
const mixin_1 = require("../../../helpers/mixin");
const helpers_1 = require("../../../helpers");
function queryParamsMixin(entity) {
    let QueryParamsMixin = class QueryParamsMixin {
        transform(value) {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const generalErrors = [];
                let metadataRepo = this.repository.metadata;
                const relationName = this.request.params[constants_1.PARAMS_RELATION_NAME];
                if (relationName) {
                    generalErrors.push(...yield helpers_1.checkResourceRelationName(relationName, metadataRepo));
                    if (generalErrors.length > 0) {
                        throw new common_1.BadRequestException(generalErrors);
                    }
                    metadataRepo = metadataRepo.relations.find(relation => {
                        return relation.propertyPath === relationName;
                    }).inverseEntityMetadata;
                }
                generalErrors.push(...yield helpers_1.checkQueryFilterParam(value, metadataRepo));
                generalErrors.push(...yield helpers_1.checkQueryIncludeParam(value, metadataRepo));
                generalErrors.push(...yield helpers_1.checkQuerySortParam(value, metadataRepo));
                if (generalErrors.length > 0) {
                    throw new common_1.BadRequestException(generalErrors);
                }
                return value;
            });
        }
    };
    tslib_1.__decorate([
        typeorm_1.InjectRepository(entity),
        tslib_1.__metadata("design:type", Object)
    ], QueryParamsMixin.prototype, "repository", void 0);
    tslib_1.__decorate([
        common_1.Inject(core_1.REQUEST),
        tslib_1.__metadata("design:type", Object)
    ], QueryParamsMixin.prototype, "request", void 0);
    QueryParamsMixin = tslib_1.__decorate([
        common_1.Injectable()
    ], QueryParamsMixin);
    return mixin_1.mixin(QueryParamsMixin);
}
exports.queryParamsMixin = queryParamsMixin;
//# sourceMappingURL=query-params.js.map